==> holado-0.11.1.tar.gz: holado-0.11.1/src/holado_report/__init__.py <==
# -*- coding: utf-8 -*-

#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################


def configure_module():
    from holado.holado_config import Config
    from holado_python.common.tools.datetime import TIMEZONE_UTC
    
    Config.report_timezone = TIMEZONE_UTC

def dependencies():
    return ["holado_multitask"]

def register():
    from holado.common.context.session_context import SessionContext
    
    from holado_report.report.report_manager import ReportManager
    SessionContext.instance().services.register_service_type("report_manager", ReportManager, 
                                                        lambda m: m.initialize(SessionContext.instance().multitask_manager))

==> holado-0.13.8.tar.gz: holado-0.13.8/src/holado_report/__init__.py <==
# -*- coding: utf-8 -*-

#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################


def configure_module():
    from holado.holado_config import Config
    from holado_python.common.tools.datetime import TIMEZONE_UTC
    
    Config.report_timezone = TIMEZONE_UTC
    Config.report_compact_datetime_period = True
    Config.campaign_manager_import_report_name = 'report_detailed_scenario.xml'

def dependencies():
    return ["holado_multitask"]

def register():
    from holado.common.context.session_context import SessionContext
    
    from holado_report.report.report_manager import ReportManager
    SessionContext.instance().services.register_service_type("report_manager", ReportManager, 
                                                        lambda m: m.initialize(SessionContext.instance().multitask_manager))
